'use strict'
if (process.env.NODE_ENV === 'production') {
  module.exports = require('./redux-toolkit-react.production.min.cjs')
} else {
  module.exports = require('./redux-toolkit-react.development.cjs')
}